<img align="left" width="250" height="250" src="https://i.imgur.com/8jqfpoz.png"> 

### Package version
__version__ = 1.0; as of 06 Oct 2021

<br/>
<br/>
<br/>
<br/>
<br/>
<br/>
<br/>

***
### Content

`covfunc.py` - covariance functions

`meanfunc.py` - mean functions

`meanfield.py` - mean-field inference functions

`nonparametric.py` - non-parametric variational inference functions (experimental)

`evidence.py`  - evidence calculation functions using the Perrakis et al. (2014) method

<br/>

***

